Name:           python-scrypt
Version:        0.8.27
Release:        3%{?dist}
Summary:        Python bindings for the scrypt key derivation function

License:        BSD-2-Clause
URL:            https://github.com/holgern/py-scrypt
Source0:        %{pypi_source scrypt}

BuildRequires:  gcc
BuildRequires:  openssl-devel
BuildRequires:  python3-devel
BuildRequires:  python3-pytest

%global _description %{expand:
Scrypt is useful when encrypting password as it is possible to specify
a minimum amount of time to use when encrypting and decrypting.
If, for example, a password takes 0.05 seconds to verify, a user won't notice
the slight delay when signing in, but doing a brute force search of several
billion passwords will take a considerable amount of time. This is in contrast
to more traditional hash functions such as MD5 or the SHA family which can be
implemented extremely fast on cheap hardware.}

%description %_description

%package -n     python3-scrypt
Summary:        Bindings for the scrypt key derivation function library
Provides:       bundled(scrypt) = 1.2.1

%description -n python3-scrypt %_description


%prep
%autosetup -n scrypt-%{version}
# remove useless shebang
sed -i '1d' scrypt/scrypt.py

%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l '_scrypt*' scrypt


%check
%pyproject_check_import

%{pytest}


%files -n python3-scrypt -f %{pyproject_files}
%doc README.rst


%changelog
* Tue Jul 15 2025 Jonny Heggheim <hegjon@gmail.com> - 0.8.27-3
- Removed deprecated macros
  https://fedoraproject.org/wiki/Changes/DeprecateSetuppyMacros

* Mon Jun 02 2025 Python Maint <python-maint@redhat.com> - 0.8.27-2
- Rebuilt for Python 3.14

* Thu May 08 2025 Jonny Heggheim <hegjon@gmail.com> - 0.8.27-1
- Updated to version 0.8.27

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.20-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Wed Sep 04 2024 Miroslav Suchý <msuchy@redhat.com> - 0.8.20-8
- convert license to SPDX

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.20-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Jun 07 2024 Python Maint <python-maint@redhat.com> - 0.8.20-6
- Rebuilt for Python 3.13

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.20-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.20-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.20-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 13 2023 Python Maint <python-maint@redhat.com> - 0.8.20-2
- Rebuilt for Python 3.12

* Thu Feb  2 2023 Haïkel Guémar <hguemar@fedoraproject.org> - 0.8.20-1
- Upstream 0.8.20

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 0.8.0-20
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Sep 14 2021 Sahana Prasad <sahana@redhat.com> - 0.8.0-18
- Rebuilt with OpenSSL 3.0.0

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.8.0-16
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-13
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-11
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-10
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Oct 12 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.8.0-7
- Python2 binary package has been removed
  See https://fedoraproject.org/wiki/Changes/Mass_Python_2_Package_Removal

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-5
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Iryna Shcherbina <ishcherb@redhat.com> - 0.8.0-4
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jun  7 2017 Haïkel Guémar <hguemar@fedoraproject.org> - 0.8.0-2
- Add virtual provides for bundled code

* Fri Jun  2 2017 Haïkel Guémar <hguemar@fedoraproject.org> - 0.8.0-1
- Initial package.
